@@ -9,7 +9,7 @@ extends 'Org::Element';
 
 use Time::HiRes qw(gettimeofday tv_interval);
 
-our $VERSION = '0.39'; # VERSION
+our $VERSION = '0.40'; # VERSION
 
 has tags                    => (is => 'rw');
 has todo_states             => (is => 'rw');
@@ -122,7 +122,7 @@ sub __parse_args {
     return [] unless defined($args) && length($args);
     #$log->tracef("args = %s", $args);
     my @args;
-    while ($args =~ /$arg_re (?:\s+|\z)/xgo) {
+    while ($args =~ /$arg_re (?:\s+|\z)/xg) {
         if (defined $+{squote}) {
             push @args, $+{squote};
         } elsif (defined $+{dquote}) {
@@ -376,7 +376,7 @@ sub _parse {
             my $todo_kw_re = "(?:".
                 join("|", map {quotemeta}
                          @{$self->todo_states}, @{$self->done_states}) . ")";
-            if ($title =~ s/^($todo_kw_re)(\s+|\W)/$2/o) {
+            if ($title =~ s/^($todo_kw_re)(\s+|\W)/$2/) {
                 my $state = $1;
                 $title =~ s/^\s+//;
                 $el->is_todo(1);
@@ -387,11 +387,11 @@ sub _parse {
             # recognize priority
             my $prio_re = "(?:".
                 join("|", map {quotemeta} @{$self->priorities}) . ")";
-            if ($title =~ s/\[#($prio_re)\]\s*//o) {
+            if ($title =~ s/\[#($prio_re)\]\s*//) {
                 $el->priority($1);
             }
 
-            # recognize priority
+            # recognize progress cookie
             if ($title =~ s!\[(\d+%|\d+/\d+)\]\s*!!o) {
                 $el->progress($1);
             }
@@ -773,7 +773,7 @@ Org::Document - Represent an Org document
 
 =head1 VERSION
 
-This document describes version 0.39 of Org::Document (from Perl distribution Org-Parser), released on 2014-07-17.
+This document describes version 0.40 of Org::Document (from Perl distribution Org-Parser), released on 2014-08-28.
 
 =head1 SYNOPSIS
 
@@ -845,7 +845,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Org-Parser
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Org-Parser>.
+Source repository is at L<https://github.com/perlancar/perl-Org-Parser>.
 
 =head1 BUGS
 
@@ -857,11 +857,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
