@@ -7,7 +7,7 @@ use Log::Any qw($log);
 
 use String::Escape qw(elide printable);
 
-our $VERSION = '0.39'; # VERSION
+our $VERSION = '0.40'; # VERSION
 
 sub _dump_ts {
     my ($self, $ts) = @_;
@@ -42,8 +42,10 @@ sub _dump {
     # per-element important info
     if ($type eq 'Headline') {
         $line .= " l=".$el->level;
-        $line .= " tags ".join(",", @{$el->tags}) if $el->tags;
+        $line .= " tags=[".join(",", @{$el->tags})."]" if $el->tags;
         $line .= " todo=".$el->todo_state if $el->todo_state;
+        $line .= " prio=".$el->priority if $el->priority;
+        $line .= " prog=".$el->progress if $el->progress;
     } elsif ($type eq 'Footnote') {
         $line .= " name=".($el->name // "");
     } elsif ($type eq 'Block') {
@@ -129,7 +131,7 @@ Org::Dump - Show Org document/element object in a human-friendly format
 
 =head1 VERSION
 
-This document describes version 0.39 of Org::Dump (from Perl distribution Org-Parser), released on 2014-07-17.
+This document describes version 0.40 of Org::Dump (from Perl distribution Org-Parser), released on 2014-08-28.
 
 =head1 FUNCTIONS
 
@@ -145,7 +147,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Org-Parser
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Org-Parser>.
+Source repository is at L<https://github.com/perlancar/perl-Org-Parser>.
 
 =head1 BUGS
 
@@ -157,11 +159,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
