@@ -7,7 +7,7 @@ use File::Slurp::Tiny qw(read_file);
 use Org::Document;
 use Scalar::Util qw(blessed);
 
-our $VERSION = '0.39'; # VERSION
+our $VERSION = '0.40'; # VERSION
 
 sub parse {
     my ($self, $arg, $opts) = @_;
@@ -83,7 +83,7 @@ Org::Parser - Parse Org documents
 
 =head1 VERSION
 
-This document describes version 0.39 of Org::Parser (from Perl distribution Org-Parser), released on 2014-07-17.
+This document describes version 0.40 of Org::Parser (from Perl distribution Org-Parser), released on 2014-08-28.
 
 =head1 SYNOPSIS
 
@@ -235,7 +235,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Org-Parser
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Org-Parser>.
+Source repository is at L<https://github.com/perlancar/perl-Org-Parser>.
 
 =head1 BUGS
 
@@ -247,11 +247,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
